summaryrefslogtreecommitdiffstats
path: root/sys
diff options
context:
space:
mode:
authorsimokawa <simokawa@FreeBSD.org>2002-12-26 06:50:09 +0000
committersimokawa <simokawa@FreeBSD.org>2002-12-26 06:50:09 +0000
commit24039264286813b2f510f337372b0ca6cb9bd702 (patch)
tree778a16d4d8a7fcf98b4a27bb67cc8df7d6991255 /sys
parente90de498fd6b8984d0f2531d0ff1ac8f79669336 (diff)
downloadFreeBSD-src-24039264286813b2f510f337372b0ca6cb9bd702.zip
FreeBSD-src-24039264286813b2f510f337372b0ca6cb9bd702.tar.gz
Cosmetic change. s/Firewire/FireWire/.
Diffstat (limited to 'sys')
-rw-r--r--sys/dev/firewire/firewire.c6
-rw-r--r--sys/dev/firewire/firewire.h2
-rw-r--r--sys/dev/firewire/fwmem.c2
-rw-r--r--sys/dev/firewire/fwohci_pci.c2
-rw-r--r--sys/dev/firewire/if_fwe.c4
-rw-r--r--sys/dev/firewire/sbp.c4
6 files changed, 10 insertions, 10 deletions
diff --git a/sys/dev/firewire/firewire.c b/sys/dev/firewire/firewire.c
index 4046a2e..08f8b61 100644
--- a/sys/dev/firewire/firewire.c
+++ b/sys/dev/firewire/firewire.c
@@ -58,9 +58,9 @@
#include <dev/firewire/iec68113.h>
int firewire_debug=0;
-SYSCTL_NODE(_hw, OID_AUTO, firewire, CTLFLAG_RD, 0, "Firewire Subsystem");
+SYSCTL_NODE(_hw, OID_AUTO, firewire, CTLFLAG_RD, 0, "FireWire Subsystem");
SYSCTL_INT(_debug, OID_AUTO, firewire_debug, CTLFLAG_RW, &firewire_debug, 0,
- "Firewire driver debug flag");
+ "FireWire driver debug flag");
#define FW_MAXASYRTY 4
#define FW_MAXDEVRCNT 4
@@ -474,7 +474,7 @@ fw_asystart(struct fw_xfer *xfer)
static int
firewire_match( device_t dev )
{
- device_set_desc(dev, "IEEE1394(Firewire) bus");
+ device_set_desc(dev, "IEEE1394(FireWire) bus");
return -140;
}
diff --git a/sys/dev/firewire/firewire.h b/sys/dev/firewire/firewire.h
index c41bb33..032e59b 100644
--- a/sys/dev/firewire/firewire.h
+++ b/sys/dev/firewire/firewire.h
@@ -528,7 +528,7 @@ struct fw_crom_buf {
};
#define FWSTMAXCHUNK 16
/*
- * Firewire specific system requests.
+ * FireWire specific system requests.
*/
#define FW_SSTDV _IOWR('S', 85, unsigned int)
#define FW_SSTBUF _IOWR('S', 86, struct fw_isobufreq)
diff --git a/sys/dev/firewire/fwmem.c b/sys/dev/firewire/fwmem.c
index 509036f..ed0eed9 100644
--- a/sys/dev/firewire/fwmem.c
+++ b/sys/dev/firewire/fwmem.c
@@ -58,7 +58,7 @@ static int fwmem_speed=2, fwmem_debug=0;
static struct fw_eui64 fwmem_eui64;
SYSCTL_DECL(_hw_firewire);
SYSCTL_NODE(_hw_firewire, OID_AUTO, fwmem, CTLFLAG_RD, 0,
- "Firewire Memory Access");
+ "FireWire Memory Access");
SYSCTL_UINT(_hw_firewire_fwmem, OID_AUTO, eui64_hi, CTLFLAG_RW,
&fwmem_eui64.hi, 0, "Fwmem target EUI64 high");
SYSCTL_UINT(_hw_firewire_fwmem, OID_AUTO, eui64_low, CTLFLAG_RW,
diff --git a/sys/dev/firewire/fwohci_pci.c b/sys/dev/firewire/fwohci_pci.c
index a2a0684..ef22f19 100644
--- a/sys/dev/firewire/fwohci_pci.c
+++ b/sys/dev/firewire/fwohci_pci.c
@@ -233,7 +233,7 @@ fwohci_pci_attach(device_t self)
err = device_probe_and_attach(sc->fc.bdev);
if (err) {
- device_printf(self, "Firewire init failed\n");
+ device_printf(self, "FireWire init failed\n");
fwohci_pci_detach(self);
return EIO;
}
diff --git a/sys/dev/firewire/if_fwe.c b/sys/dev/firewire/if_fwe.c
index dca079d..41f0361 100644
--- a/sys/dev/firewire/if_fwe.c
+++ b/sys/dev/firewire/if_fwe.c
@@ -76,7 +76,7 @@ static int fwedebug = 0;
static int stream_ch = 1;
MALLOC_DECLARE(M_FWE);
-MALLOC_DEFINE(M_FWE, "if_fwe", "Ethernet over Firewire interface");
+MALLOC_DEFINE(M_FWE, "if_fwe", "Ethernet over FireWire interface");
SYSCTL_INT(_debug, OID_AUTO, if_fwe_debug, CTLFLAG_RW, &fwedebug, 0, "");
SYSCTL_DECL(_hw_firewire);
SYSCTL_NODE(_hw_firewire, OID_AUTO, fwe, CTLFLAG_RD, 0,
@@ -135,7 +135,7 @@ fwe_probe(device_t dev)
return(ENXIO);
}
- device_set_desc(dev, "Ethernet over Firewire");
+ device_set_desc(dev, "Ethernet over FireWire");
return (0);
}
diff --git a/sys/dev/firewire/sbp.c b/sys/dev/firewire/sbp.c
index 08cd52f..6ddb863 100644
--- a/sys/dev/firewire/sbp.c
+++ b/sys/dev/firewire/sbp.c
@@ -300,7 +300,7 @@ static void sbp_detach_target __P((struct sbp_target *));
static void sbp_timeout __P((void *arg));
static void sbp_mgm_orb __P((struct sbp_dev *, int));
-MALLOC_DEFINE(M_SBP, "sbp", "SBP-II/Firewire");
+MALLOC_DEFINE(M_SBP, "sbp", "SBP-II/FireWire");
/* cam related functions */
static void sbp_action(struct cam_sim *sim, union ccb *ccb);
@@ -1251,7 +1251,7 @@ END_DEBUG
case T_DIRECT:
/*
* XXX Convert Direct Access device to RBC.
* I've never seen Firewire DA devices which support READ_6.
*/
#if 1
if (SID_TYPE(inq) == T_DIRECT)
@@ -1251,7 +1251,7 @@ END_DEBUG
/*
* XXX Convert Direct Access device to RBC.
- * I've never seen Firewire DA devices which support READ_6.
+ * I've never seen FireWire DA devices which support READ_6.
*/
#if 1
OpenPOWER on IntegriCloud